window.Gleam.initSearch([{"doc":"for_the_crows","title":"for_the_crows","content":"# crow\n\n[![Package Version](https://img.shields.io/hexpm/v/crow)](https://hex.pm/packages/crow)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/crow/)\n\nA Gleam project\n\n## Quick start\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n\n## Installation\n\nIf available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add crow\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/crow&gt;.\n\n## Presentation \n\nPRESENTATION - Gleam is expressive\n\nGleam is fairly simple and in some ways syntax is less expressive than what\ncan be found in erlang or elixir: \n\n* Lack of literals\n* Lack of branching options\n* Lack of macro system\n* No behaviour or protocol system\n\nBut is just as capable of modelling most problem domains:\n\n* &quot;Open&quot; domain through types public types\n* Constained set of operations through opaque types\n  * Api might be &quot;flexible&quot;, next = gamestate -&gt; next -&gt; gamestate\n  * Api might be &quot;precise&quot;, next = gamestate -&gt; gamestate\n\nMay or not require assertion checks when depending on Result types\n  * Result types can be composed together\n  * But composition can also be achieved with pipes\n  * Or a custom mechanism to apply types or functions\n\nWe may add to this type through Generics.\n\nTODO: Recover gamestate file here\n\npub type MoveError {\n  NoPath\n  OutOfBounds\n  Blocked\n  NoPiece\n}\n\npub fn move(\n  in board: Board,\n  from from: Position,\n  to to: Position,\n) -&gt; Result(Board, MoveError) {\n  try Nil = check_bounds(at: from, in: board)\n  try Nil = check_bounds(at: to, in: board)\n  try Nil = check_piece(at: from, in: board)\n  try Nil = check_move(from: from, to: to, in: board)\n  Ok(update(at: from, to: to, in: board))\n}\n","url":"index.html"},{"doc":"crow/coordinate","title":"Coordinate","content":"pub type Coordinate {\n  Coordinate(x: Int, y: Int)\n}\n\nCoordinate(x: Int, y: Int)\n\n\nSynonyms:\ncrow/coordinate.Coordinate\ncrow/coordinate Coordinate","url":"crow/coordinate.html#Coordinate"},{"doc":"crow/coordinate","title":"add","content":"pub fn add(m: Coordinate, n: Coordinate) -&gt; Coordinate\n\nSynonyms:\ncrow/coordinate.add\ncrow/coordinate add","url":"crow/coordinate.html#add"},{"doc":"crow/coordinate","title":"equal","content":"pub fn equal(coordinate_a: Coordinate, coordinate_b: Coordinate) -&gt; Bool\n\nSynonyms:\ncrow/coordinate.equal\ncrow/coordinate equal","url":"crow/coordinate.html#equal"},{"doc":"crow/coordinate","title":"multiply","content":"pub fn multiply(m: Coordinate, n: Coordinate) -&gt; Coordinate\n\nSynonyms:\ncrow/coordinate.multiply\ncrow/coordinate multiply","url":"crow/coordinate.html#multiply"},{"doc":"crow/coordinate","title":"substract","content":"pub fn substract(m: Coordinate, n: Coordinate) -&gt; Coordinate\n\nSynonyms:\ncrow/coordinate.substract\ncrow/coordinate substract","url":"crow/coordinate.html#substract"},{"doc":"crow/coordinate","title":"crow/coordinate","content":"","url":"crow/coordinate.html"},{"doc":"crow/board/rule","title":"Rule","content":"pub opaque type Rule(t, error)\n\n\nSynonyms:\ncrow/board/rule.Rule\ncrow/board/rule Rule","url":"crow/board/rule.html#Rule"},{"doc":"crow/board/rule","title":"apply","content":"pub fn apply(data: a, rule: Rule(a, b)) -&gt; Result(a, b)\n\nSynonyms:\ncrow/board/rule.apply\ncrow/board/rule apply","url":"crow/board/rule.html#apply"},{"doc":"crow/board/rule","title":"new","content":"pub fn new(rule: fn(a) -&gt; Result(a, b)) -&gt; Rule(a, b)\n\nSynonyms:\ncrow/board/rule.new\ncrow/board/rule new","url":"crow/board/rule.html#new"},{"doc":"crow/board/rule","title":"then","content":"pub fn then(rule: Rule(a, b), then_do: Rule(a, b)) -&gt; Rule(a, b)\n\nSynonyms:\ncrow/board/rule.then\ncrow/board/rule then","url":"crow/board/rule.html#then"},{"doc":"crow/board/rule","title":"crow/board/rule","content":"","url":"crow/board/rule.html"},{"doc":"crow/board/path","title":"Blocked","content":"pub type Blocked {\n  FriendlyPiece\n  RivalPiece\n  OutOfBounds\n  StepLimit\n  Capture\n}\n\nFriendlyPiece\n\n\nRivalPiece\n\n\nOutOfBounds\n\n\nStepLimit\n\n\nCapture\n\n\nSynonyms:\ncrow/board/path.Blocked\ncrow/board/path Blocked","url":"crow/board/path.html#Blocked"},{"doc":"crow/board/path","title":"Path","content":"pub type Path {\n  Path(positions: List(Coordinate), capture: Option(Coordinate))\n}\n\nPath(positions: List(Coordinate), capture: Option(Coordinate))\n\n\nSynonyms:\ncrow/board/path.Path\ncrow/board/path Path","url":"crow/board/path.html#Path"},{"doc":"crow/board/path","title":"Trace","content":"pub type Trace {\n  Trace(\n    position: Coordinate,\n    direction: Coordinate,\n    step: Int,\n    path: List(Coordinate),\n  )\n}\n\nTrace(\n  position: Coordinate,\n  direction: Coordinate,\n  step: Int,\n  path: List(Coordinate),\n)\n\n\nSynonyms:\ncrow/board/path.Trace\ncrow/board/path Trace","url":"crow/board/path.html#Trace"},{"doc":"crow/board/path","title":"build","content":"pub fn build(trace: Trace, rule: Rule(Trace, Blocked)) -&gt; Path\n\nSynonyms:\ncrow/board/path.build\ncrow/board/path build","url":"crow/board/path.html#build"},{"doc":"crow/board/path","title":"new","content":"pub fn new(from: Coordinate, trajectory: Coordinate, rule: Rule(\n    Trace,\n    Blocked,\n  )) -&gt; Path\n\nSynonyms:\ncrow/board/path.new\ncrow/board/path new","url":"crow/board/path.html#new"},{"doc":"crow/board/path","title":"crow/board/path","content":"","url":"crow/board/path.html"},{"doc":"crow/player","title":"Player","content":"pub type Player {\n  Player(id: String)\n}\n\nPlayer(id: String)\n\n\nSynonyms:\ncrow/player.Player\ncrow/player Player","url":"crow/player.html#Player"},{"doc":"crow/player","title":"crow/player","content":"","url":"crow/player.html"},{"doc":"crow/piece","title":"Piece","content":"pub type Piece {\n  Pawn\n  Rook\n  Bishop\n  Knight\n  Queen\n  King\n}\n\nPawn\n\n\nRook\n\n\nBishop\n\n\nKnight\n\n\nQueen\n\n\nKing\n\n\nSynonyms:\ncrow/piece.Piece\ncrow/piece Piece","url":"crow/piece.html#Piece"},{"doc":"crow/piece","title":"crow/piece","content":"","url":"crow/piece.html"},{"doc":"crow/players/facing","title":"Facing","content":"pub opaque type Facing\n\n\nSynonyms:\ncrow/players/facing.Facing\ncrow/players/facing Facing","url":"crow/players/facing.html#Facing"},{"doc":"crow/players/facing","title":"add","content":"pub fn add(facing: Facing, player: Player, direction: Coordinate) -&gt; Facing\n\nSynonyms:\ncrow/players/facing.add\ncrow/players/facing add","url":"crow/players/facing.html#add"},{"doc":"crow/players/facing","title":"get","content":"pub fn get(facing: Facing, player: Player) -&gt; Coordinate\n\nSynonyms:\ncrow/players/facing.get\ncrow/players/facing get","url":"crow/players/facing.html#get"},{"doc":"crow/players/facing","title":"new","content":"pub fn new() -&gt; Facing\n\nSynonyms:\ncrow/players/facing.new\ncrow/players/facing new","url":"crow/players/facing.html#new"},{"doc":"crow/players/facing","title":"crow/players/facing","content":"","url":"crow/players/facing.html"},{"doc":"crow/players","title":"Players","content":"pub opaque type Players\n\n\nSynonyms:\ncrow/players.Players\ncrow/players Players","url":"crow/players.html#Players"},{"doc":"crow/players","title":"add","content":"pub fn add(players: Players, player: Player, direction: Coordinate) -&gt; Players\n\nSynonyms:\ncrow/players.add\ncrow/players add","url":"crow/players.html#add"},{"doc":"crow/players","title":"get_current","content":"pub fn get_current(players: Players) -&gt; Player\n\nSynonyms:\ncrow/players.get_current\ncrow/players get_current","url":"crow/players.html#get_current"},{"doc":"crow/players","title":"get_facing","content":"pub fn get_facing(players: Players, player: Player) -&gt; Coordinate\n\nSynonyms:\ncrow/players.get_facing\ncrow/players get_facing","url":"crow/players.html#get_facing"},{"doc":"crow/players","title":"get_player","content":"pub fn get_player(players: Players, at: Int) -&gt; Player\n\nSynonyms:\ncrow/players.get_player\ncrow/players get_player","url":"crow/players.html#get_player"},{"doc":"crow/players","title":"get_players","content":"pub fn get_players(players: Players) -&gt; List(Player)\n\nSynonyms:\ncrow/players.get_players\ncrow/players get_players","url":"crow/players.html#get_players"},{"doc":"crow/players","title":"new","content":"pub fn new() -&gt; Players\n\nSynonyms:\ncrow/players.new\ncrow/players new","url":"crow/players.html#new"},{"doc":"crow/players","title":"rotate","content":"pub fn rotate(players: Players) -&gt; Players\n\nSynonyms:\ncrow/players.rotate\ncrow/players rotate","url":"crow/players.html#rotate"},{"doc":"crow/players","title":"crow/players","content":"","url":"crow/players.html"},{"doc":"crow/round/turn","title":"Turn","content":"pub opaque type Turn\n\n\nSynonyms:\ncrow/round/turn.Turn\ncrow/round/turn Turn","url":"crow/round/turn.html#Turn"},{"doc":"crow/round/turn","title":"get_turn","content":"pub fn get_turn(turn: Turn) -&gt; Int\n\nSynonyms:\ncrow/round/turn.get_turn\ncrow/round/turn get_turn","url":"crow/round/turn.html#get_turn"},{"doc":"crow/round/turn","title":"new","content":"pub fn new() -&gt; Turn\n\nSynonyms:\ncrow/round/turn.new\ncrow/round/turn new","url":"crow/round/turn.html#new"},{"doc":"crow/round/turn","title":"next","content":"pub fn next(t: Turn) -&gt; Turn\n\nSynonyms:\ncrow/round/turn.next\ncrow/round/turn next","url":"crow/round/turn.html#next"},{"doc":"crow/round/turn","title":"crow/round/turn","content":"","url":"crow/round/turn.html"},{"doc":"crow/round/phase","title":"Phase","content":"pub opaque type Phase\n\n\nSynonyms:\ncrow/round/phase.Phase\ncrow/round/phase Phase","url":"crow/round/phase.html#Phase"},{"doc":"crow/round/phase","title":"new","content":"pub fn new() -&gt; Phase\n\nSynonyms:\ncrow/round/phase.new\ncrow/round/phase new","url":"crow/round/phase.html#new"},{"doc":"crow/round/phase","title":"next","content":"pub fn next(phase: Phase) -&gt; Phase\n\nSynonyms:\ncrow/round/phase.next\ncrow/round/phase next","url":"crow/round/phase.html#next"},{"doc":"crow/round/phase","title":"crow/round/phase","content":"","url":"crow/round/phase.html"},{"doc":"crow/round","title":"Round","content":"pub opaque type Round\n\n\nSynonyms:\ncrow/round.Round\ncrow/round Round","url":"crow/round.html#Round"},{"doc":"crow/round","title":"get_turn","content":"pub fn get_turn(round: Round) -&gt; Int\n\nSynonyms:\ncrow/round.get_turn\ncrow/round get_turn","url":"crow/round.html#get_turn"},{"doc":"crow/round","title":"new","content":"pub fn new() -&gt; Round\n\nSynonyms:\ncrow/round.new\ncrow/round new","url":"crow/round.html#new"},{"doc":"crow/round","title":"next","content":"pub fn next(round: Round) -&gt; Round\n\nSynonyms:\ncrow/round.next\ncrow/round next","url":"crow/round.html#next"},{"doc":"crow/round","title":"crow/round","content":"","url":"crow/round.html"},{"doc":"crow/board/grid","title":"Error","content":"pub type Error {\n  NegativeInitialization\n  OutOfBounds\n  NoContent\n}\n\nNegativeInitialization\n\n\nOutOfBounds\n\n\nNoContent\n\n\nSynonyms:\ncrow/board/grid.Error\ncrow/board/grid Error","url":"crow/board/grid.html#Error"},{"doc":"crow/board/grid","title":"Grid","content":"pub type Grid(content) {\n  Grid(limits: Limits, positions: Map(Coordinate, content))\n}\n\nGrid(limits: Limits, positions: Map(Coordinate, content))\n\n\nSynonyms:\ncrow/board/grid.Grid\ncrow/board/grid Grid","url":"crow/board/grid.html#Grid"},{"doc":"crow/board/grid","title":"Limits","content":"pub type Limits {\n  Limits(x: Coordinate, y: Coordinate)\n}\n\nLimits(x: Coordinate, y: Coordinate)\n\n\nSynonyms:\ncrow/board/grid.Limits\ncrow/board/grid Limits","url":"crow/board/grid.html#Limits"},{"doc":"crow/board/grid","title":"delete","content":"pub fn delete(in grid: Grid(a), at position: Coordinate) -&gt; Grid(\n  a,\n)\n\nSynonyms:\ncrow/board/grid.delete\ncrow/board/grid delete","url":"crow/board/grid.html#delete"},{"doc":"crow/board/grid","title":"filter","content":"pub fn filter(grid: Grid(a), apply: fn(Coordinate, a) -&gt; Bool) -&gt; Grid(\n  a,\n)\n\nSynonyms:\ncrow/board/grid.filter\ncrow/board/grid filter","url":"crow/board/grid.html#filter"},{"doc":"crow/board/grid","title":"in_bounds","content":"pub fn in_bounds(in grid: Grid(a), at position: Coordinate) -&gt; Result(\n  Coordinate,\n  Error,\n)\n\nSynonyms:\ncrow/board/grid.in_bounds\ncrow/board/grid in_bounds","url":"crow/board/grid.html#in_bounds"},{"doc":"crow/board/grid","title":"map","content":"pub fn map(grid: Grid(a), apply: fn(Coordinate, a) -&gt; a) -&gt; Grid(\n  a,\n)\n\nSynonyms:\ncrow/board/grid.map\ncrow/board/grid map","url":"crow/board/grid.html#map"},{"doc":"crow/board/grid","title":"new","content":"pub fn new(x: Int, y: Int) -&gt; Result(Grid(a), Error)\n\nSynonyms:\ncrow/board/grid.new\ncrow/board/grid new","url":"crow/board/grid.html#new"},{"doc":"crow/board/grid","title":"retrieve","content":"pub fn retrieve(in grid: Grid(a), at position: Coordinate) -&gt; Result(\n  a,\n  Error,\n)\n\nSynonyms:\ncrow/board/grid.retrieve\ncrow/board/grid retrieve","url":"crow/board/grid.html#retrieve"},{"doc":"crow/board/grid","title":"set","content":"pub fn set(in grid: Grid(a), at position: Coordinate, value value: a) -&gt; Result(\n  Grid(a),\n  Error,\n)\n\nSynonyms:\ncrow/board/grid.set\ncrow/board/grid set","url":"crow/board/grid.html#set"},{"doc":"crow/board/grid","title":"update","content":"pub fn update(in grid: Grid(a), at from: Coordinate, to to: Coordinate) -&gt; Result(\n  Grid(a),\n  Error,\n)\n\nSynonyms:\ncrow/board/grid.update\ncrow/board/grid update","url":"crow/board/grid.html#update"},{"doc":"crow/board/grid","title":"crow/board/grid","content":"","url":"crow/board/grid.html"},{"doc":"crow/board/check","title":"Check","content":"pub type Check {\n  Check(\n    player: Player,\n    piece: Piece,\n    paths: List(Path),\n    facing_direction: Coordinate,\n  )\n}\n\nCheck(\n  player: Player,\n  piece: Piece,\n  paths: List(Path),\n  facing_direction: Coordinate,\n)\n\n\nSynonyms:\ncrow/board/check.Check\ncrow/board/check Check","url":"crow/board/check.html#Check"},{"doc":"crow/board/check","title":"new","content":"pub fn new(player: Player, piece: Piece, facing_direction: Coordinate) -&gt; Check\n\nSynonyms:\ncrow/board/check.new\ncrow/board/check new","url":"crow/board/check.html#new"},{"doc":"crow/board/check","title":"crow/board/check","content":"","url":"crow/board/check.html"},{"doc":"crow/board/direction","title":"bottom_left","content":"pub const bottom_left: Coordinate = Coordinate(-1, -1)\n\nSynonyms:\ncrow/board/direction.bottom_left\ncrow/board/direction bottom_left","url":"crow/board/direction.html#bottom_left"},{"doc":"crow/board/direction","title":"bottom_left_jump","content":"pub const bottom_left_jump: Coordinate = Coordinate(-1, -2)\n\nSynonyms:\ncrow/board/direction.bottom_left_jump\ncrow/board/direction bottom_left_jump","url":"crow/board/direction.html#bottom_left_jump"},{"doc":"crow/board/direction","title":"bottom_right","content":"pub const bottom_right: Coordinate = Coordinate(1, -1)\n\nSynonyms:\ncrow/board/direction.bottom_right\ncrow/board/direction bottom_right","url":"crow/board/direction.html#bottom_right"},{"doc":"crow/board/direction","title":"bottom_right_jump","content":"pub const bottom_right_jump: Coordinate = Coordinate(1, -2)\n\nSynonyms:\ncrow/board/direction.bottom_right_jump\ncrow/board/direction bottom_right_jump","url":"crow/board/direction.html#bottom_right_jump"},{"doc":"crow/board/direction","title":"down","content":"pub const down: Coordinate = Coordinate(0, -1)\n\nSynonyms:\ncrow/board/direction.down\ncrow/board/direction down","url":"crow/board/direction.html#down"},{"doc":"crow/board/direction","title":"hold","content":"pub const hold: Coordinate = Coordinate(0, 0)\n\nSynonyms:\ncrow/board/direction.hold\ncrow/board/direction hold","url":"crow/board/direction.html#hold"},{"doc":"crow/board/direction","title":"left","content":"pub const left: Coordinate = Coordinate(-1, 0)\n\nSynonyms:\ncrow/board/direction.left\ncrow/board/direction left","url":"crow/board/direction.html#left"},{"doc":"crow/board/direction","title":"left_bottom_jump","content":"pub const left_bottom_jump: Coordinate = Coordinate(-2, -1)\n\nSynonyms:\ncrow/board/direction.left_bottom_jump\ncrow/board/direction left_bottom_jump","url":"crow/board/direction.html#left_bottom_jump"},{"doc":"crow/board/direction","title":"left_top_jump","content":"pub const left_top_jump: Coordinate = Coordinate(-2, 1)\n\nSynonyms:\ncrow/board/direction.left_top_jump\ncrow/board/direction left_top_jump","url":"crow/board/direction.html#left_top_jump"},{"doc":"crow/board/direction","title":"right","content":"pub const right: Coordinate = Coordinate(1, 0)\n\nSynonyms:\ncrow/board/direction.right\ncrow/board/direction right","url":"crow/board/direction.html#right"},{"doc":"crow/board/direction","title":"right_top_jump","content":"pub const right_top_jump: Coordinate = Coordinate(2, 1)\n\nSynonyms:\ncrow/board/direction.right_top_jump\ncrow/board/direction right_top_jump","url":"crow/board/direction.html#right_top_jump"},{"doc":"crow/board/direction","title":"top_bottom_jump","content":"pub const top_bottom_jump: Coordinate = Coordinate(2, -1)\n\nSynonyms:\ncrow/board/direction.top_bottom_jump\ncrow/board/direction top_bottom_jump","url":"crow/board/direction.html#top_bottom_jump"},{"doc":"crow/board/direction","title":"top_left","content":"pub const top_left: Coordinate = Coordinate(-1, 1)\n\nSynonyms:\ncrow/board/direction.top_left\ncrow/board/direction top_left","url":"crow/board/direction.html#top_left"},{"doc":"crow/board/direction","title":"top_left_jump","content":"pub const top_left_jump: Coordinate = Coordinate(-1, 2)\n\nSynonyms:\ncrow/board/direction.top_left_jump\ncrow/board/direction top_left_jump","url":"crow/board/direction.html#top_left_jump"},{"doc":"crow/board/direction","title":"top_right","content":"pub const top_right: Coordinate = Coordinate(1, 1)\n\nSynonyms:\ncrow/board/direction.top_right\ncrow/board/direction top_right","url":"crow/board/direction.html#top_right"},{"doc":"crow/board/direction","title":"top_right_jump","content":"pub const top_right_jump: Coordinate = Coordinate(1, 2)\n\nSynonyms:\ncrow/board/direction.top_right_jump\ncrow/board/direction top_right_jump","url":"crow/board/direction.html#top_right_jump"},{"doc":"crow/board/direction","title":"up","content":"pub const up: Coordinate = Coordinate(0, 1)\n\nSynonyms:\ncrow/board/direction.up\ncrow/board/direction up","url":"crow/board/direction.html#up"},{"doc":"crow/board/direction","title":"crow/board/direction","content":"","url":"crow/board/direction.html"},{"doc":"crow/board/piece_path","title":"MoveLimit","content":"pub type MoveLimit {\n  Continuous\n  Limited(n: Int)\n}\n\nContinuous\n\n\nLimited(n: Int)\n\n\nSynonyms:\ncrow/board/piece_path.MoveLimit\ncrow/board/piece_path MoveLimit","url":"crow/board/piece_path.html#MoveLimit"},{"doc":"crow/board/piece_path","title":"path","content":"pub fn path(board: Grid(Check), from: Coordinate) -&gt; List(Path)\n\nSynonyms:\ncrow/board/piece_path.path\ncrow/board/piece_path path","url":"crow/board/piece_path.html#path"},{"doc":"crow/board/piece_path","title":"crow/board/piece_path","content":"","url":"crow/board/piece_path.html"},{"doc":"crow/board","title":"Board","content":"pub opaque type Board\n\n\nSynonyms:\ncrow/board.Board\ncrow/board Board","url":"crow/board.html#Board"},{"doc":"crow/board","title":"all","content":"pub fn all(board: Board) -&gt; Map(Coordinate, Check)\n\nSynonyms:\ncrow/board.all\ncrow/board all","url":"crow/board.html#all"},{"doc":"crow/board","title":"deploy","content":"pub fn deploy(board: Board, position: Coordinate, player: Player, facing: Coordinate, piece: Piece) -&gt; Board\n\nSynonyms:\ncrow/board.deploy\ncrow/board deploy","url":"crow/board.html#deploy"},{"doc":"crow/board","title":"get","content":"pub fn get(board: Board, position: Coordinate) -&gt; Check\n\nSynonyms:\ncrow/board.get\ncrow/board get","url":"crow/board.html#get"},{"doc":"crow/board","title":"move","content":"pub fn move(board: Board, from: Coordinate, to: Coordinate) -&gt; Board\n\nSynonyms:\ncrow/board.move\ncrow/board move","url":"crow/board.html#move"},{"doc":"crow/board","title":"new","content":"pub fn new() -&gt; Board\n\nSynonyms:\ncrow/board.new\ncrow/board new","url":"crow/board.html#new"},{"doc":"crow/board","title":"crow/board","content":"","url":"crow/board.html"},{"doc":"crow","title":"Check","content":"pub type Check {\n  Check(\n    player: Player,\n    piece: Piece,\n    path: List(Coordinate),\n    captures: List(Coordinate),\n  )\n}\n\nCheck(\n  player: Player,\n  piece: Piece,\n  path: List(Coordinate),\n  captures: List(Coordinate),\n)\n\n\nSynonyms:\ncrow.Check\ncrow Check","url":"crow.html#Check"},{"doc":"crow","title":"Gamestate","content":"pub type Gamestate {\n  Gamestate(\n    players: players.Players,\n    round: round.Round,\n    board: board.Board,\n  )\n}\n\nGamestate(\n  players: players.Players,\n  round: round.Round,\n  board: board.Board,\n)\n\n\nSynonyms:\ncrow.Gamestate\ncrow Gamestate","url":"crow.html#Gamestate"},{"doc":"crow","title":"deploy","content":"pub fn deploy(state: Gamestate, position: String, player: String, piece: Piece) -&gt; Gamestate\n\nSynonyms:\ncrow.deploy\ncrow deploy","url":"crow.html#deploy"},{"doc":"crow","title":"get_current_player","content":"pub fn get_current_player(state: Gamestate) -&gt; String\n\nSynonyms:\ncrow.get_current_player\ncrow get_current_player","url":"crow.html#get_current_player"},{"doc":"crow","title":"get_player","content":"pub fn get_player(state: Gamestate, at: Int) -&gt; String\n\nSynonyms:\ncrow.get_player\ncrow get_player","url":"crow.html#get_player"},{"doc":"crow","title":"get_players","content":"pub fn get_players(state: Gamestate) -&gt; List(String)\n\nSynonyms:\ncrow.get_players\ncrow get_players","url":"crow.html#get_players"},{"doc":"crow","title":"get_position","content":"pub fn get_position(state: Gamestate, position: String) -&gt; Check\n\nSynonyms:\ncrow.get_position\ncrow get_position","url":"crow.html#get_position"},{"doc":"crow","title":"get_positions","content":"pub fn get_positions(state: Gamestate) -&gt; Map(Coordinate, Check)\n\nSynonyms:\ncrow.get_positions\ncrow get_positions","url":"crow.html#get_positions"},{"doc":"crow","title":"get_turn","content":"pub fn get_turn(state: Gamestate) -&gt; Int\n\nSynonyms:\ncrow.get_turn\ncrow get_turn","url":"crow.html#get_turn"},{"doc":"crow","title":"move","content":"pub fn move(state: Gamestate, from_position: String, to_position: String) -&gt; Gamestate\n\nSynonyms:\ncrow.move\ncrow move","url":"crow.html#move"},{"doc":"crow","title":"new","content":"pub fn new() -&gt; Gamestate\n\nSynonyms:\ncrow.new\ncrow new","url":"crow.html#new"},{"doc":"crow","title":"next","content":"pub fn next(state: Gamestate) -&gt; Gamestate\n\nSynonyms:\ncrow.next\ncrow next","url":"crow.html#next"},{"doc":"crow","title":"players","content":"pub fn players(state: Gamestate, p1: String, p2: String) -&gt; Gamestate\n\nSynonyms:\ncrow.players\ncrow players","url":"crow.html#players"},{"doc":"crow","title":"crow","content":"","url":"crow.html"},{"doc":"session","title":"Message","content":"pub type Message(state) {\n  Join(String)\n  Set(state)\n  Close\n  GetPlayers(Subject(List(String)))\n  GetGame(Subject(Option(state)))\n}\n\nJoin(String)\n\n\nSet(state)\n\n\nClose\n\n\nGetPlayers(Subject(List(String)))\n\n\nGetGame(Subject(Option(state)))\n\n\nSynonyms:\nsession.Message\nsession Message","url":"session.html#Message"},{"doc":"session","title":"close","content":"pub fn close(subject: Subject(Message(a))) -&gt; Nil\n\nSynonyms:\nsession.close\nsession close","url":"session.html#close"},{"doc":"session","title":"get_game","content":"pub fn get_game(subject: Subject(Message(a))) -&gt; Option(a)\n\nSynonyms:\nsession.get_game\nsession get_game","url":"session.html#get_game"},{"doc":"session","title":"get_players","content":"pub fn get_players(subject: Subject(Message(a))) -&gt; List(String)\n\nSynonyms:\nsession.get_players\nsession get_players","url":"session.html#get_players"},{"doc":"session","title":"join","content":"pub fn join(subject: Subject(Message(a)), name: String) -&gt; Nil\n\nSynonyms:\nsession.join\nsession join","url":"session.html#join"},{"doc":"session","title":"start","content":"pub fn start(name: String) -&gt; Result(\n  Subject(Message(a)),\n  StartError,\n)\n\nSynonyms:\nsession.start\nsession start","url":"session.html#start"},{"doc":"session","title":"start_link","content":"pub fn start_link(name: String) -&gt; Result(Pid, Dynamic)\n\nSynonyms:\nsession.start_link\nsession start_link","url":"session.html#start_link"},{"doc":"session","title":"update","content":"pub fn update(subject: Subject(Message(a)), state: a) -&gt; Nil\n\nSynonyms:\nsession.update\nsession update","url":"session.html#update"},{"doc":"session","title":"session","content":"","url":"session.html"}]);